@@ -367,6 +367,14 @@ class Person{
 	    CS::setSessionKey('CertEmails', $emails);
     }
 
+    /**
+     * Delete the e-mails registered for a user from the sesssion information
+     */
+    public function clearRegCertEmails()
+    {
+        CS::deleteSessionKey('CertEmails');
+    }
+
     private function retrieveRegCertEmails()
     {
 	    $em = CS::getSessionKey('CertEmails');
@@ -884,42 +892,42 @@ class Person{
 
 		if (empty($this->eppn)) {
 			$permission->setPermission(false);
-			$permission->addReason($this->translateTag('l10n_reas_malfeppn', 'reasons'));
+			$permission->addReason($translator->getTextForTag('l10n_reas_malfeppn', 'reasons'));
 		}
 
 		if (empty($this->given_name)) {
 			$permission->setPermission(false);
-			$permission->addReason($this->translateTag('l10n_reas_nogivenname', 'reasons'));
+			$permission->addReason($translator->getTextForTag('l10n_reas_nogivenname', 'reasons'));
 		}
 
 		if (empty($this->email)) {
 			$permission->setPermission(false);
-			$permission->addReason($this->translateTag('l10n_reas_noemailaddr', 'reasons'));
+			$permission->addReason($translator->getTextForTag('l10n_reas_noemailaddr', 'reasons'));
 		}
 
 		if (is_null($this->getNREN()->getCountry()) || $this->getNREN()->getCountry() == "") {
 			$permission->setPermission(false);
-			$permission->addReason($this->translateTag('l10n_reas_nocountryname', 'reasons'));
+			$permission->addReason($translator->getTextForTag('l10n_reas_nocountryname', 'reasons'));
 		}
 
 		$subscriberOrgName = $this->subscriber->getOrgName();
 		if (empty($subscriberOrgName)) {
 			$permission->setPermission(false);
-			$permission->addReason($this->translateTag('l10n_reas_malfsubsname', 'reasons'));
+			$permission->addReason($translator->getTextForTag('l10n_reas_malfsubsname', 'reasons'));
 		}
 
 		if (Config::get_config('capi_test') &&
 		    Config::get_config('ca_mode') === CA_COMODO &&
 		    $subscriberOrgName == ConfusaConstants::$CAPI_TEST_O_PREFIX) {
 			$permission->setPermission(false);
-			$permission->addReason($this->translateTag('l10n_reas_malfsubsname', 'reasons'));
+			$permission->addReason($translator->getTextForTag('l10n_reas_malfsubsname', 'reasons'));
 		}
 
 		if (empty($this->entitlement)
 				|| !$this->testEntitlementAttribute(Config::get_config('entitlement_user'))) {
 			$permission->setPermission(false);
 			$permission->addReason(Config::get_config('entitlement_user') . " " .
-			                       $this->translateTag('l10n_reas_noentitlement', 'reasons'));
+			                       $translator->getTextForTag('l10n_reas_noentitlement', 'reasons'));
 		}
 
 		$query = "SELECT org_state FROM subscribers WHERE name=?";
@@ -931,9 +939,9 @@ class Person{
 
 		if (count($res) == 0) {
 			$permission->setPermission(false);
-			$permission->addReason($this->translateTag('l10n_instunkn1', 'reasons') . " " .
+			$permission->addReason($translator->getTextForTag('l10n_instunkn1', 'reasons') . " " .
 			                       $this->subscriber->getIdPName() . " " .
-			                       $this->translateTag('l10n_instunkn2', 'reasons'));
+			                       $translator->getTextForTag('l10n_instunkn2', 'reasons'));
 			return $permission;
 		} else if (count($res) > 1) {
 			throw new CGE_AuthException("More than one DB-entry with same subscriberOrgName " .
@@ -942,9 +950,9 @@ class Person{
 
 		if ($res[0]['org_state'] !== 'subscribed') {
 			$permission->setPermission(false);
-			$permission->addReason($this->translateTag('l10n_instnsubscr1', 'reasons') . " " .
+			$permission->addReason($translator->getTextForTag('l10n_instnsubscr1', 'reasons') . " " .
 			                       $this->subscriber->getIdPName() . " " .
-			                       $this->translateTag('l10n_instnsubscr2', 'reasons'));
+			                       $translator->getTextForTag('l10n_instnsubscr2', 'reasons'));
 		}
 
 		return $permission;
