@@ -118,19 +118,7 @@ abstract class Confusa_Auth
 			}
 			if(!is_null($map['cn'])) {
 				if (array_key_exists($map['cn'], $attributes)) {
-					$cn = Input::sanitizePersonName($attributes[$map['cn']][0]);
-					if ($cn !== $attributes[$map['cn']][0]) {
-						/* need to keep track of issued warning,
-						 * some pages call ecoratePerson twice */
-						static $cn_changed_seen = false;
-						if (!$cn_changed_seen) {
-							$cn_changed_seen = true;
-							$msg = "Your CN contains characters deemed illegal in the certificate <br />".
-								"Original: " . htmlentities($attributes[$map['cn']][0], ENT_COMPAT, "UTF-8") . " <br />" .
-								"Current: $cn";
-							Framework::error_output($msg);
-						}
-					}
+					$cn = mysql_real_escape_string($attributes[$map['cn']][0]);
 					$this->person->setName($cnPrefix . $cn);
 				}
 			} /* end map has cn */
