@@ -1,7 +1,8 @@
 <?php
 require_once 'confusa_include.php';
-require_once 'framework.php';
-require_once 'person.php';
+require_once 'Content_Page.php';
+require_once 'Framework.php';
+require_once 'Person.php';
 require_once 'classTextile.php';
 
 class CP_About_NREN extends Content_Page
@@ -14,13 +15,16 @@ class CP_About_NREN extends Content_Page
 
 	public function process()
 	{
-		if ($this->person->isAuth()) {
-			$logo = "view_logo.php?nren=" . $this->person->getNREN();
-			$this->tpl->assign('logo', $logo);
-			$about_text = $this->person->getNREN()->getAboutText($this->person);
-			$this->tpl->assign('text_info', $about_text);
+		$nren = $this->person->getNREN();
+
+		if (isset($nren)) {
+			$aboutText = $nren->getAboutText($this->person);
+		} else {
+			$this->tpl->assign('content', $this->tpl->fetch('about_nren.tpl'));
+			return;
 		}
 
+		$this->tpl->assign('text_info', $aboutText);
 		$this->tpl->assign('content', $this->tpl->fetch('about_nren.tpl'));
 	}
 
